<?php
defined('BASEPATH') or exit('No direct script access allowed');

class ParserFile extends CI_Controller
{
    protected $rutaDiaria = FCPATH . "DOWNLOADS/DAILY/format";
    protected $rutaMensual = FCPATH . "DOWNLOADS/MONTH/format";
    protected $esquema = array('cbc-place-ext', 'cac-place-ext', 'cbc', 'cac', 'ns1');

    public function __construct()
    {
        parent::__construct();
        $this->load->helper('file');
    }

    public function index()
    {
        $files = get_filenames($this->rutaDiaria, true);

        $contadorArchivos = 0;
        foreach ($files as $file) {

            $entrada = file_get_contents($file);
            $xml = simplexml_load_string($entrada);

            $aux = 0;
            $resultEntries = array();
            foreach ($xml->entry as $clave => $row) {
                $arrayDeletedEntries = $xml->children('at', true);

                $resultEntries[$aux]['contractInfo'] = $this->nodoContractFolderStatus($row);

                $resultEntries[$aux]['locatedContractingParty'] = $this->nodoLocatedContractingParty($row);

                $resultEntries[$aux]['party'] = $this->nodoParty($row);

                //$resultEntries[] = $this->nodoParentLocatedParty($row);

                $resultEntries[$aux]['procurementProject'] = $this->nodoPresupuesto($row);

                $resultEntries[$aux]['procurementProjectLot'] = $this->nodoProcurementProjectLot($row);

                $resultEntries[$aux]['tenderingTerms'] = $this->nodoTenderingTerms($row);

                $resultEntries[$aux]['tenderingProcess'] = $this->nodoTenderingProcess($row);

                $resultEntries[$aux]['tenderingResult'] = $this->nodoTenderResult($row);

                $resultEntries[$aux]['legalDocs'] = $this->nodoLegalDoc($row);

                $resultEntries[$aux]['techicalDocs'] = $this->nodoTechnicalDocumentReference($row);

                $resultEntries[$aux]['validNoticeInfo'] = $this->nodoValidNoticeInfo($row);

                $resultEntries[$aux]['generalDocs'] = $this->nodoGeneralDocuments($row);

                $resultEntries[$aux]['additionalDocs'] = $this->nodoAdditionalDocumentReference($row);

                $aux++;
            }

            $str = print_r($resultEntries, true);

            file_put_contents($this->rutaDiaria . "/text" . $contadorArchivos . ".txt", $str);

            $contadorArchivos++;

        }
    }

    private function nodoContractFolderStatus($xml)
    {
        $resultEntries = array();
        if (isset($xml->ContractFolderStatus)) {
            $resultEntries['ContractFolderID'] = (string) $xml->ContractFolderStatus->ContractFolderID;
            $resultEntries['ContractFolderStatusCode'] = (string) $xml->ContractFolderStatus->ContractFolderStatusCode;
            $resultEntries['ContractFolderStatusCodeAttr'] = (string) $xml->ContractFolderStatus->ContractFolderStatusCode->attributes()['listURI'];
        }
        $resultFinal = $this->array_remove_empty($resultEntries);
        return $resultFinal;
    }

    private function nodoLocatedContractingParty($xml)
    {
        $resultEntries = array();
        if (isset($xml->ContractFolderStatus->LocatedContractingParty)) {
            $LocatedContractingParty = $xml->ContractFolderStatus->LocatedContractingParty;

            $resultEntries['contractingPartyTypeCode'] = $this->existNodo($LocatedContractingParty, "ContractingPartyTypeCode", 'string');
            $resultEntries['activityCode'] = $this->existNodo($LocatedContractingParty, "ActivityCode", 'string');
            $resultEntries['buyerProfileURIID'] = $this->existNodo($LocatedContractingParty, "BuyerProfileURIID", 'string');

            if (isset($LocatedContractingParty->ParentLocatedParty)) {
                //$resultEntries['activityCode'] = $this->existNodo($LocatedContractingParty->ParentLocatedParty, "PartyName", 'string');

                $this->RecurseXML($LocatedContractingParty->ParentLocatedParty);
            }
        }
        $resultFinal = $this->array_remove_empty($resultEntries);
        return $resultFinal;
    }

    private function nodoParty($xml)
    {
        $resultEntries = array();
        $contractFolder = $xml->ContractFolderStatus->LocatedContractingParty;

        if (isset($contractFolder->Party)) {
            //Datos Empresa -> direccion,nif, etc
            //LocatedContractingParty->Party
            $party = $contractFolder->Party;
            $resultEntries['websiteURI'] = $this->existNodo($party, "WebsiteURI", 'string');
            $resultEntries['partyIdentification'] = $this->existNodo($party, "PartyIdentification", 'array');
            $resultEntries['partyName'] = $this->existNodo($party->PartyName, "Name", 'string');
            $resultEntries['address']['city'] = $this->existNodo($party->PostalAddress, "CityName", 'string');
            $resultEntries['address']['codpostal'] = $this->existNodo($party->PostalAddress, "PostalZone", 'string');
            $resultEntries['address']['direccion'] = $this->existNodo($party->PostalAddress->AddressLine, "Line", 'string');
            $resultEntries['address']['country'] = $this->existNodo($party->PostalAddress->Country, "Name", 'string');
            $resultEntries['contact']['name'] = $this->existNodo($party->Contact, "Name", 'string');
            $resultEntries['contact']['email'] = $this->existNodo($party->Contact, "ElectronicMail", 'string');
        }
        $resultFinal = $this->array_remove_empty($resultEntries);
        return $resultFinal;
    }

    private function nodoPresupuesto($xml)
    {
        $resultEntries = array();

        $procurementProject = $xml->ContractFolderStatus->ProcurementProject;

        if (isset($procurementProject)) {
            //ProcurementProject

            $resultEntries['name'] = $this->existNodo($procurementProject, 'Name', 'string');
            $resultEntries['typeCode'] = $this->existNodo($procurementProject, 'TypeCode', 'string');
            $resultEntries['subTypeCode'] = $this->existNodo($procurementProject, 'SubTypeCode', 'string');

            if (isset($procurementProject->BudgetAmount)) {
                $resultEntries['estimatedOverallContractAmount'] = $this->existNodo($procurementProject->BudgetAmount, 'EstimatedOverallContractAmount', 'string');
                $resultEntries['totalAmount'] = $this->existNodo($procurementProject->BudgetAmount, 'TotalAmount', 'string');
                $resultEntries['taxExclusiveAmount'] = $this->existNodo($procurementProject->BudgetAmount, 'TaxExclusiveAmount', 'string');
            }

            if (isset($procurementProject->RequiredCommodityClassification)) {
                for ($i = 0; $i < count($procurementProject->RequiredCommodityClassification); $i++) {
                    $resultEntries['itemClassification']['value'] = $this->existNodo($procurementProject->RequiredCommodityClassification[$i], 'ItemClassificationCode', 'string');
                    $resultEntries['itemClassification']['attr'] = $procurementProject->RequiredCommodityClassification[$i]->ItemClassificationCode->attributes();
                }
            }

            if (isset($procurementProject->RealizedLocation)) {
                $resultEntries['countrySubentity'] = $this->existNodo($procurementProject->RealizedLocation, 'CountrySubentity', 'string');
                $resultEntries['countrySubentityCode'] = $this->existNodo($procurementProject->RealizedLocation, 'CountrySubentityCode', 'string');
                if (isset($procurementProject->RealizedLocation->Address)) {
                    $resultEntries['cityName'] = $this->existNodo($procurementProject->RealizedLocation->Address->Country, 'CityName', 'string');
                    $resultEntries['IdentificationCode'] = $this->existNodo($procurementProject->RealizedLocation->Address->Country, 'IdentificationCode', 'string');
                    $resultEntries['countryName'] = $this->existNodo($procurementProject->RealizedLocation->Address->Country, 'Name', 'string');
                }
            }

            $resultEntries['durationMesure'] = $this->existNodo($procurementProject->PlannedPeriod, 'DurationMeasure', 'string');
            if (isset($procurementProject->PlannedPeriod->DurationMeasure)) {
                $resultEntries['medida'] = $procurementProject->PlannedPeriod->DurationMeasure->attributes();
            }

            $resultEntries['contractExtension'] = $this->existNodo($procurementProject->ContractExtension, 'OptionsDescription', 'string');
        }

        $resultFinal = $this->array_remove_empty($resultEntries);
        return $resultFinal;
    }

    private function nodoProcurementProjectLot($xml)
    {
        $resultEntries = array();
        $procurementProjectLot = $xml->ContractFolderStatus->ProcurementProjectLot;

        if (isset($procurementProjectLot)) {
            for ($i = 0; $i < count($procurementProjectLot); $i++) {
                $resultEntries[$i]['id'] = $this->existNodo($procurementProjectLot[$i], 'ID', 'string');
                $resultEntries[$i]['name'] = $this->existNodo($procurementProjectLot[$i]->ProcurementProject, 'Name', 'string');
                $resultEntries[$i]['totalAmount'] = $this->existNodo($procurementProjectLot[$i]->ProcurementProject->BudgetAmount, 'TotalAmount', 'string');
                $resultEntries[$i]['taxExclusiveAmount'] = $this->existNodo($procurementProjectLot[$i]->ProcurementProject->BudgetAmount, 'TaxExclusiveAmount', 'string');
                $resultEntries[$i]['itemClassificationCode'] = $this->existNodo($procurementProjectLot[$i]->ProcurementProject->RequiredCommodityClassification, 'ItemClassificationCode', 'string');
                if (isset($procurementProjectLot[$i]->RealizedLocation)) {
                    $resultEntries[$i]['countrySubentity'] = $this->existNodo($procurementProjectLot[$i]->ProcurementProject->RealizedLocation, 'CountrySubentity', 'string');
                    $resultEntries[$i]['countrySubentityCode'] = $this->existNodo($procurementProjectLot[$i]->ProcurementProject->RealizedLocation, 'CountrySubentityCode', 'string');
                    $resultEntries[$i]['identificationCode'] = $this->existNodo($procurementProjectLot[$i]->ProcurementProject->RealizedLocation->Address->Country, 'IdentificationCode', 'string');
                    $resultEntries[$i]['name'] = $this->existNodo($procurementProjectLot[$i]->ProcurementProject->RealizedLocation->Address->Country, 'Name', 'string');
                }
            }
        }
        $resultFinal = $this->array_remove_empty($resultEntries);
        return $resultFinal;
    }

    private function nodoTenderResult($xml)
    {
        $resultEntries = array();
        $tenderResult = $xml->ContractFolderStatus->TenderResult;
        for ($i = 0; $i < count($tenderResult); $i++) {
            $resultEntries[$i]['resultCode'] = $this->existNodo($tenderResult[$i], 'ResultCode', 'string');
            $resultEntries[$i]['description'] = $this->existNodo($tenderResult[$i], 'Description', 'string');
            $resultEntries[$i]['awardDate'] = $this->existNodo($tenderResult[$i], 'AwardDate', 'string');
            $resultEntries[$i]['receivedTenderQuantity'] = $this->existNodo($tenderResult[$i], 'ReceivedTenderQuantity', 'string');
            $resultEntries[$i]['lowerTenderAmount'] = $this->existNodo($tenderResult[$i], 'LowerTenderAmount', 'string');
            $resultEntries[$i]['higherTenderAmount'] = $this->existNodo($tenderResult[$i], 'HigherTenderAmount', 'string');
            $resultEntries[$i]['startDate'] = $this->existNodo($tenderResult[$i], 'StartDate', 'string');
            $resultEntries[$i]['smeawardedIndicator'] = $this->existNodo($tenderResult[$i], 'SMEAwardedIndicator', 'string');
            //AwardedTenderedProject
            $resultEntries[$i]['contract']['id'] = $this->existNodo($tenderResult[$i]->Contract, 'ID', 'string');
            $resultEntries[$i]['contract']['issueDate'] = $this->existNodo($tenderResult[$i]->Contract, 'IssueDate', 'string');

            $winningParty = $tenderResult[$i]->WinningParty;
            if (isset($winningParty)) {
                $resultEntries[$i]['partyIdentification'] = $this->existNodo($winningParty->PartyIdentification, 'ID', 'string');
                $resultEntries[$i]['partyName'] = $this->existNodo($winningParty->PartyName, 'Name', 'string');
            }
            $awardedTenderedProject = $tenderResult[$i]->AwardedTenderedProject;
            if (isset($awardedTenderedProject)) {
                $resultEntries[$i]['procurementProjectLotID'] = $this->existNodo($awardedTenderedProject, 'ProcurementProjectLotID', 'string');
                $resultEntries[$i]['TaxExclusiveAmount'] = $this->existNodo($awardedTenderedProject->LegalMonetaryTotal, 'TaxExclusiveAmount', 'string');
                $resultEntries[$i]['PayableAmount'] = $this->existNodo($awardedTenderedProject->LegalMonetaryTotal, 'PayableAmount', 'string');
            }
        }
        $resultFinal = $this->array_remove_empty($resultEntries);
        return $resultFinal;
    }

    private function nodoTenderingTerms($xml)
    {
        $resultEntries = array();
        $TenderingTerms = $xml->ContractFolderStatus->TenderingTerms;

        if (isset($TenderingTerms)) {

            $resultEntries['requiredCurriculaIndicator'] = $this->existNodo($TenderingTerms, 'RequiredCurriculaIndicator', 'string');
            $resultEntries['variantConstraintIndicator'] = $this->existNodo($TenderingTerms, 'VariantConstraintIndicator', 'string');
            $resultEntries['fundingProgramCode'] = $this->existNodo($TenderingTerms, 'FundingProgramCode', 'string');
            $resultEntries['requiredFinancialGuarantee']['guaranteeTypeCode'] = $this->existNodo($TenderingTerms->RequiredFinancialGuarantee, 'GuaranteeTypeCode', 'string');
            $resultEntries['requiredFinancialGuarantee']['amountRate'] = $this->existNodo($TenderingTerms->RequiredFinancialGuarantee, 'AmountRate', 'string');
            $resultEntries['procurementLegislationDocumentReference'] = $this->existNodo($TenderingTerms->ProcurementLegislationDocumentReference, 'ID', 'string');

            $tendererQualificationRequest = $TenderingTerms->TendererQualificationRequest;
            if (isset($tendererQualificationRequest)) {
                for ($i = 0; $i < count($tendererQualificationRequest); $i++) {
                    $resultEntries['tendererQualificationRequest']['evaluationCriteriaTypeCode'] = $this->existNodo($tendererQualificationRequest[$i]->TechnicalEvaluationCriteria, 'EvaluationCriteriaTypeCode', 'string');
                    $resultEntries['tendererQualificationRequest']['description'] = $this->existNodo($tendererQualificationRequest[$i]->TechnicalEvaluationCriteria, 'Description', 'string');
                }
            }

            $financialEvaluationCriteria = $TenderingTerms->TendererQualificationRequest->FinancialEvaluationCriteria;
            if (isset($financialEvaluationCriteria)) {
                for ($i = 0; $i < count($financialEvaluationCriteria); $i++) {
                    $resultEntries['financialEvaluationCriteria']['evaluationCriteriaTypeCode'] = $this->existNodo($financialEvaluationCriteria[$i]->EvaluationCriteriaTypeCode, 'EvaluationCriteriaTypeCode', 'string');
                    $resultEntries['financialEvaluationCriteria']['description'] = $this->existNodo($financialEvaluationCriteria[$i]->EvaluationCriteriaTypeCode, 'Description', 'string');
                }
            }

            $specificTendererRequirement = $TenderingTerms->TendererQualificationRequest->SpecificTendererRequirement;
            if (isset($specificTendererRequirement)) {
                for ($i = 0; $i < count($specificTendererRequirement); $i++) {
                    $resultEntries['financialEvaluationCriteria']['evaluationCriteriaTypeCode'] = $this->existNodo($specificTendererRequirement[$i]->SpecificTendererRequirement, 'RequirementTypeCode', 'string');
                }
            }

            //$Language = $this->existNodo($contractFolderCac->TenderingTerms->children('cac', true)->Language, 'cbc', 'array');
        }
        $resultFinal = $this->array_remove_empty($resultEntries);
        return $resultFinal;
    }

    private function nodoTenderingProcess($xml)
    {
        $resultEntries = array();
        $tenderingProcess = $xml->ContractFolderStatus->TenderingProcess;

        if (isset($tenderingProcess)) {
            //TenderingProcess
            $resultEntries['procedureCode'] = $this->existNodo($tenderingProcess, 'ProcedureCode', 'string');
            $resultEntries['urgencyCode'] = $this->existNodo($tenderingProcess, 'UrgencyCode', 'string');
            $resultEntries['partPresentationCode'] = $this->existNodo($tenderingProcess, 'PartPresentationCode', 'string');
            $resultEntries['contractingSystemCode'] = $this->existNodo($tenderingProcess, 'ContractingSystemCode', 'string');
            $resultEntries['submissionMethodCode'] = $this->existNodo($tenderingProcess, 'SubmissionMethodCode', 'string');
            $resultEntries['deadLineEndDate'] = $this->existNodo($tenderingProcess->TenderSubmissionDeadlinePeriod, 'EndDate', 'string');
            $resultEntries['deadLineEndTime'] = $this->existNodo($tenderingProcess->TenderSubmissionDeadlinePeriod, 'EndTime', 'string');
            $resultEntries['documentAvailablePeriod_EndDate'] = $this->existNodo($tenderingProcess->DocumentAvailabilityPeriod, 'EndDate', 'string');
            $resultEntries['documentAvailablePeriod_EndTime'] = $this->existNodo($tenderingProcess->DocumentAvailabilityPeriod, 'EndTime', 'string');
        }
        $resultFinal = $this->array_remove_empty($resultEntries);
        return $resultFinal;
    }

    private function nodoLegalDoc($xml)
    {
        $resultEntries = array();
        $legalDocumentReference = $xml->ContractFolderStatus->LegalDocumentReference;

        if (isset($legalDocumentReference)) {

            for ($i = 0; $i < count($legalDocumentReference); $i++) {
                $resultEntries[$i]['id'] = $this->existNodo($legalDocumentReference[$i], 'ID', 'string');
                $resultEntries[$i]['attachment'] = $this->existNodo($legalDocumentReference[$i]->Attachment->ExternalReference, 'URI', 'string');
                $resultEntries[$i]['documentHash'] = $this->existNodo($legalDocumentReference[$i]->Attachment->ExternalReference, 'DocumentHash', 'string');
            }

        }
        $resultFinal = $this->array_remove_empty($resultEntries);
        return $resultFinal;
    }

    private function nodoTechnicalDocumentReference($xml)
    {
        $resultEntries = array();
        $technicalDocumentReference = $xml->ContractFolderStatus->TechnicalDocumentReference;

        if (isset($technicalDocumentReference)) {

            for ($i = 0; $i < count($technicalDocumentReference); $i++) {
                $resultEntries[$i]['id'] = $this->existNodo($technicalDocumentReference[$i], 'ID', 'string');
                $resultEntries[$i]['attachment'] = $this->existNodo($technicalDocumentReference[$i]->Attachment->ExternalReference, 'URI', 'string');
                $resultEntries[$i]['documentHash'] = $this->existNodo($technicalDocumentReference[$i]->Attachment->ExternalReference, 'DocumentHash', 'string');
            }

        }
        $resultFinal = $this->array_remove_empty($resultEntries);
        return $resultFinal;
    }

    private function nodoAdditionalDocumentReference($xml)
    {
        $resultEntries = array();
        $additionalDocumentReference = $xml->ContractFolderStatus->AdditionalDocumentReference;

        if (isset($additionalDocumentReference)) {

            for ($i = 0; $i < count($additionalDocumentReference); $i++) {
                $resultEntries[$i]['id'] = $this->existNodo($additionalDocumentReference[$i], 'ID', 'string');
                $resultEntries[$i]['attachment'] = $this->existNodo($additionalDocumentReference[$i]->Attachment->ExternalReference, 'URI', 'string');
                $resultEntries[$i]['documentHash'] = $this->existNodo($additionalDocumentReference[$i]->Attachment->ExternalReference, 'DocumentHash', 'string');
            }

        }
        $resultFinal = $this->array_remove_empty($resultEntries);
        return $resultFinal;
    }

    private function nodoValidNoticeInfo($xml)
    {
        $resultEntries = array();
        $validNoticeInfo = $xml->ContractFolderStatus->ValidNoticeInfo;

        if (isset($validNoticeInfo)) {
            for ($i = 0; $i < count($validNoticeInfo); $i++) {
                $resultEntries[$i]['NoticeTypeCode'] = $this->existNodo($validNoticeInfo[$i], 'NoticeTypeCode', 'string');
                $resultEntries[$i]['PublicationMediaName'] = $this->existNodo($validNoticeInfo[$i]->AdditionalPublicationStatus, 'PublicationMediaName', 'string');
                $resultEntries[$i]['IssueDate'] = $this->existNodo($validNoticeInfo[$i]->AdditionalPublicationStatus->AdditionalPublicationDocumentReference, 'IssueDate', 'string');
            }
        }
        $resultFinal = $this->array_remove_empty($resultEntries);
        return $resultFinal;
    }

    private function nodoGeneralDocuments($xml)
    {
        $resultEntries = array();
        $generalDocument = $xml->ContractFolderStatus->GeneralDocument->GeneralDocumentDocumentReference;

        if (isset($generalDocument)) {

            for ($i = 0; $i < count($generalDocument); $i++) {
                $resultEntries[$i]['id'] = $this->existNodo($generalDocument[$i], 'ID', 'string');
                $resultEntries[$i]['attachment'] = $this->existNodo($generalDocument[$i]->Attachment->ExternalReference, 'URI', 'string');
                $resultEntries[$i]['documentHash'] = $this->existNodo($generalDocument[$i]->Attachment->ExternalReference, 'DocumentHash', 'string');
            }

        }
        $resultFinal = $this->array_remove_empty($resultEntries);
        return $resultFinal;
    }

    private function existNodo($nodo, $nodoHijo, $tipo)
    {

        if (isset($nodo) && @count($nodo) > 0) {
            return $this->switchTipo($tipo, $nodo->{$nodoHijo});
        } else {
            return "";
        }
    }

    private function switchTipo($tipo, $nodo)
    {
        switch ($tipo) {
            case 'string':
                return (string) $nodo;
                break;
            case 'int':
                return (int) $nodo;
                break;
            case 'array':
                return (array) $nodo;
                break;
        }
    }

    public function RecurseXML($xml, $parent = "")
    {
        $child_count = 0;
        $result = array();
        foreach ($xml as $key => $value) {
            $child_count++;
            if ($this->RecurseXML($value, $parent . "." . $key) == 0) // no childern, aka "leaf node"
            {
                //print($parent . "." . (string) $key . " = " . (string) $value . "<BR>\n");

            }
        }
        return $child_count;
    }

    public function array_remove_empty($haystack)
    {
        foreach ($haystack as $key => $value) {
            if (is_array($value)) {
                $haystack[$key] = $this->array_remove_empty($haystack[$key]);
            }

            if (empty($haystack[$key])) {
                unset($haystack[$key]);
            }
        }

        return $haystack;
    }

	/* public function xml2array($xml)
    {
        $arr = array();

        foreach ($xml->getNamespaces() + array(null) as $prefix => $namespace) {
            foreach ($xml->attributes($namespace) as $key => $value) {
                // Add prefixes to prefixed attributes
                if (is_string($prefix)) {
                    $key = $prefix . '.' . $key;
                }
                $arr['@attributes'][$key] = (string) $value;
            }
        }

        foreach ($xml as $name => $element) {
            $value = $element->children() ? $this->xml2array($element) : trim($element);
            if ($value) {
                if (!isset($arr[$name])) {
                    $arr[$name] = $value;
                } else {
                    foreach ((array) $value as $k => $v) {
                        if (is_numeric($k)) {
                            $arr[$name][] = $v;
                        } else {
                            $arr[$name][$k] = array_merge(
                                (array) $arr[$name][$k],
                                (array) $v
                            );
                        }
                    }
                }
            }
        }

        if ($content = trim((string) $xml)) {
            $arr[] = $content;
        }

        return $arr;
    } 
	$reader = new \XMLReader;
            $reader->open($file); // where $path is the file path to the xml file

            // using a dirty trick to skip most of the xml that is irrelevant where $nodeName is the node im looking for
            // then in the next while loop i skip to the next node
            $data = array();
            while ($reader->read() && $reader->name !== "data");
            while ($reader->name === "data") {
                $doc = new \DOMDocument;
                $dom = $doc->importNode($reader->expand(), true);
                $data = $this->processDom($dom);
                $reader->next($dom->localName);
            }

	public function processDom(\DOMNode $node)
    {
        $data = [];
        /** @var \DomNode $childNode 
        foreach ($node->childNodes as $childNode) {
            // child nodes include of a lot of #text nodes which are irrelevant for me, so i just skip them
            if ($childNode->nodeName === '#text') {
                continue;
            }
            $childData = $this->processDom($childNode);
            if ($childData === null || $childData === []) {
                $data[$childNode->localName] = $childNode->nodeValue;
            } else {
                $data[$childNode->localName] = $childData;
            }
        }
        return $data;
    }
	
	*/

}

/* End of file ParserFile.php */
/* Location: ./application/controllers/ParserFile.php */
